==> php83-nextcloud-28.0.2.tgz: share/nextcloud/apps/user_status/l10n/de.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Letzter Status",
    "No recent status changes" : "Keine kürzlichen Statusänderungen",
    "In a meeting" : "In einer Besprechung",
    "Commuting" : "Pendelt",
    "Out sick" : "Krankgeschrieben",
    "Vacationing" : "Im Urlaub",
    "Out of office" : "Nicht im Büro",
    "Working remotely" : "Arbeitet aus der Ferne",
    "In a call" : "In einem Anruf",
    "User status" : "Benutzerstatus",
    "Clear status after" : "Status löschen nach",
    "Emoji for your status message" : "Emoji für Ihre Statusnachricht",
    "What is your status?" : "Wie ist dein Status?",
    "Predefined statuses" : "Vordefinierte Status",
    "Previously set" : "Zuvor eingestellt",
    "Reset status" : "Status zurücksetzen",
    "Set status" : "Status setzen",
    "Online status" : "Online-Status",
    "Status message" : "Statusnachricht",
    "Your status was set automatically" : "Dein Status wurde automatisch gesetzt",
    "Clear status message" : "Statusnachricht löschen",
    "Set status message" : "Statusnachricht setzen",
    "Reset status to \"{icon} {message}\"" : "Status auf \"{icon} {message}\" zurücksetzen",
    "Reset status to \"{message}\"" : "Status auf \"{message}\" zurücksetzen",
    "Reset status to \"{icon}\"" : "Status auf \"{icon}\" zurücksetzen",
    "There was an error saving the status" : "Es gab einen Fehler beim Speichern des Status",
    "There was an error clearing the status" : "Es gab einen Fehler beim Löschen des Status",
    "There was an error reverting the status" : "Es ist ein Fehler beim Zurücksetzen des Status aufgetreten",
    "Don't clear" : "Nicht löschen",
    "Today" : "Heute",
    "This week" : "Diese Woche",
    "Online" : "Online",
    "Away" : "Abwesend",
    "Do not disturb" : "Bitte nicht stören",
    "Invisible" : "Unsichtbar",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Es gab einen Fehler beim Speichern des neuen Status",
    "30 minutes" : "30 Minuten",
    "1 hour" : "1 Stunde",
    "4 hours" : "4 Stunden",
    "Mute all notifications" : "Alle Benachrichtigungen stummschalten",
    "Appear offline" : "Offline erscheinen",
    "View profile" : "Profil ansehen",
    "{status}, {timestamp}" : "{status}, {timestamp}"
},
"nplurals=2; plural=(n != 1);");

==> php83-nextcloud-30.0.5.tgz: share/nextcloud/apps/user_status/l10n/de.js <==
OC.L10N.register(
    "user_status",
    {
    "Recent statuses" : "Letzter Status",
    "No recent status changes" : "Keine kürzlichen Statusänderungen",
    "In a meeting" : "In einer Besprechung",
    "Commuting" : "Pendelt",
    "Out sick" : "Krankgeschrieben",
    "Vacationing" : "Im Urlaub",
    "Out of office" : "Nicht im Büro",
    "Working remotely" : "Arbeitet aus der Ferne",
    "In a call" : "In einem Anruf",
    "User status" : "Benutzerstatus",
    "Clear status after" : "Status löschen nach",
    "Emoji for your status message" : "Emoji für deine Statusnachricht",
    "What is your status?" : "Wie ist dein Status?",
    "Predefined statuses" : "Vordefinierte Status",
    "Previously set" : "Zuvor eingestellt",
    "Reset status" : "Status zurücksetzen",
    "Set status" : "Status setzen",
    "Online status" : "Online-Status",
    "Status message" : "Statusnachricht",
    "Set absence period" : "Abwesenheitszeitraum festlegen",
    "Set absence period and replacement" : "Abwesenheitszeitraum und Vertretung festlegen",
    "Your status was set automatically" : "Dein Status wurde automatisch gesetzt",
    "Clear status message" : "Statusnachricht löschen",
    "Set status message" : "Statusnachricht setzen",
    "Reset status to \"{icon} {message}\"" : "Status auf \"{icon} {message}\" zurücksetzen",
    "Reset status to \"{message}\"" : "Status auf \"{message}\" zurücksetzen",
    "Reset status to \"{icon}\"" : "Status auf \"{icon}\" zurücksetzen",
    "There was an error saving the status" : "Es gab einen Fehler beim Speichern des Status",
    "There was an error clearing the status" : "Es gab einen Fehler beim Löschen des Status",
    "There was an error reverting the status" : "Es ist ein Fehler beim Zurücksetzen des Status aufgetreten",
    "Don't clear" : "Nicht löschen",
    "Today" : "Heute",
    "This week" : "Diese Woche",
    "Online" : "Online",
    "Away" : "Abwesend",
    "Do not disturb" : "Bitte nicht stören",
    "Invisible" : "Unsichtbar",
    "Offline" : "Offline",
    "There was an error saving the new status" : "Es gab einen Fehler beim Speichern des neuen Status",
    "30 minutes" : "30 Minuten",
    "1 hour" : "1 Stunde",
    "4 hours" : "4 Stunden",
    "Mute all notifications" : "Alle Benachrichtigungen stummschalten",
    "Appear offline" : "Offline erscheinen"
},
"nplurals=2; plural=(n != 1);");
